The underlying principle is as follows. When a harmonic wave induces strain in a confined aquifer (one having aquitards above and below it), fluid flows radially into, and out of a well penetrating the aquifer. The flow-induced drawdown, $s$, is governed by the following partial differential equation, expressed in radial coordinates($r$): $$\frac{\partial^2 s}{\partial r^2} + \frac{1}{r} \frac{\partial s}{ \partial r} - \frac{S}{T}\frac{\partial s}{\partial t} = 0$$ where $S, T$ are the aquifer storativity and transmissivity respectively.
The solution to this PDE, with periodic discharge boundary conditions, gives the amplitude and phase response we wish to calculate; this was originally presented by Hsieh et al (1987), and subsequently adapted by Kitagawa et al (2011) for the case of a sealed well. The model is applicable to any quasi-static process involving harmonic, volumetric strain of an aquifer (e.g. passing Rayleigh waves, or changes in the Earth's tidal potential)
In practice, however, the presence of permeable fractures can violate the assumption of isotropic permeability, which may substantially alter the response by introducing shear-strain coupling. But these complications are beyond the scope of this model.
well_response, which takes in arguments for
well- and aquifer-parameters, and frequencies at which to
calculate the response functions. It accesses the
constants-calculation routines (i.e.
alpha_constants,omega_constants)
where appropriate; hence, the user need not worry about
those functions.There are also two helper functions included: [object Object],[object Object]
Kitagawa, Y., S. Itaba, N. Matsumoto, and N. Koisumi (2011), Frequency characteristics of the response of water pressure in a closed well to volumetric strain in the high-frequency domain, J. Geophys. Res., 116, B08301, doi:10.1029/2010JB007794.
well_response,
sensing_volume, kitplot