Learn R Programming

kitagawa (version 1.1-1)

omega_constants: Calculate any constants that depend on $\omega$

Description

This function accesses the appropriate method to calculate the $\omega$-dependent constant associated with the choice of c.type. There is currently only one such constant, corresponding to Equation 12 in Kitagawa et al (2011).

Usage

omega_constants(omega = 0, c.type = c("alpha"), ...)

## S3 method for class 'default': omega_constants(omega = 0, c.type = c("alpha"), ...)

Arguments

omega
frequency, $[rad/sec]$
c.type
the constant to calculate
...
additional params passed to calculator, i.e. S., T., Rs.

Value

  • Values of the constant repesented by c.type

Warnings

In the case c.type='alpha'(the default), the parameters S., T., and Rs. must be passed; otherwise, values are assumed to ensure the calculation does not fail, and the results are essentially meaningless. Warnings will be issued if any necessary parameters are missing, indicating default values S.=T.=Rs.=1 were used; these are physically unrealistic.

Details

This function is not likely to be needed by the user.

The radial frequency $\omega$ is formally defined as: $$\omega \equiv 2 \pi / \tau$$ where $\tau$ is the period of oscillation.

Because the computation of $\alpha$ depends also on physical properties, additional parameters can be passed through (e.g. the transmissivity).

References

Kitagawa, Y., S. Itaba, N. Matsumoto, and N. Koisumi (2011), Frequency characteristics of the response of water pressure in a closed well to volumetric strain in the high-frequency domain, J. Geophys. Res., 116, B08301, doi:10.1029/2010JB007794.

http://www.agu.org/pubs/crossref/2011/2010JB007794.shtml

See Also

alpha_constants, well_response

Examples

Run this code
omega_constants() # 0, with warnings about S., T., Rs.
omega_constants(T.=1,S.=1,Rs.=1)  # 0, no warnings
omega_constants(1:10)  # sequence, with warnings about S., T., Rs.
omega_constants(1:10,T.=1,S.=1,Rs.=1) # sequence, no warnings

Run the code above in your browser using DataLab